@@ -1,5 +1,5 @@
 """
-as
+desc.
 """
 
 from . shroodinger__equation import *
\ No newline at end of file
